%%%----------------------------------------------------------------------
%%% File    : cosb_h.erl
%%% Author  : Steve Elkins <sge@pnc0d004.us.nortel.com>
%%% Purpose : 
%%% Created :  8 Oct 2000 by Steve Elkins <sge@pnc0d004.us.nortel.com>
%%%----------------------------------------------------------------------

-module(cosb_h).
-author('sge@pnc0d004.us.nortel.com').

%%-compile(export_all).
%%-export([Function/Arity, ...]).

-behaviour(gen_event).

%% External exports
-export([start_link/0, add_handler/0]).

%% gen_event callbacks
-export([init/1, handle_event/2, handle_call/2, handle_info/2, terminate/2, code_change/3]).

-record(state, {services = []}).

%%%----------------------------------------------------------------------
%%% API
%%%----------------------------------------------------------------------
start_link() ->
    gen_event:start_link({local, cosb_h}). 

add_handler() ->
    gen_event:add_handler(cosb_em, cosb_h, []).

%%%----------------------------------------------------------------------
%%% Callback functions from gen_event
%%%----------------------------------------------------------------------

%%----------------------------------------------------------------------
%% Func: init/1
%% Returns: {ok, State}          |
%%          Other
%%----------------------------------------------------------------------
init([]) ->
    {ok, #state{}}.

%%----------------------------------------------------------------------
%% Func: handle_event/2
%% Returns: {ok, State}                                |
%%          {swap_handler, Args1, State1, Mod2, Args2} |
%%          remove_handler                              
%%----------------------------------------------------------------------
handle_event({udp, Socket, IP, Port, Block}, State) ->
    gen_udp:send(Socket, IP, Port, "you said " ++ Block),
    {ok, State};
handle_event(Event, State) ->
    {ok, State}.

%%----------------------------------------------------------------------
%% Func: handle_call/2
%% Returns: {ok, Reply, State}                                |
%%          {swap_handler, Reply, Args1, State1, Mod2, Args2} |
%%          {remove_handler, Reply}                            
%%----------------------------------------------------------------------
handle_call(Request, State) ->
    Reply = ok,
    {ok, Reply, State}.

%%----------------------------------------------------------------------
%% Func: handle_info/2
%% Returns: {ok, State}                                |
%%          {swap_handler, Args1, State1, Mod2, Args2} |
%%          remove_handler                              
%%----------------------------------------------------------------------
handle_info(Info, State) ->
    {ok, State}.

%%----------------------------------------------------------------------
%% Func: terminate/2
%% Purpose: Shutdown the server
%% Returns: any
%%----------------------------------------------------------------------
terminate(Reason, State) ->
    ok.

%%----------------------------------------------------------------------
%% Func: code_change/3
%% Purpose: Convert process state when code is changed
%% Returns: {ok, NewState}
%%----------------------------------------------------------------------
code_change(OldVsn, State, Extra) ->
    {ok, State}.

%%%----------------------------------------------------------------------
%%% Internal functions
%%%----------------------------------------------------------------------

cmd(S) ->
    {ok, List} = regexp:split(S," "),
    case List of
        ["offer" | T]  ->
            offer(T);
        ["withdraw" | T ] ->
            withdraw(T);
        ["request" | T] ->
            request(T);
        [Whatever | T] ->
            {bad_command, Whatever};
        [] ->
            {bad_command, empty}
    end.

offer(List) ->
    case List of
        [Service, Proto, Port] ->
            {offer, Service, Proto, Port};
        Whatever ->
            {bad_offer, Whatever}
    end.

withdraw(List) ->
    case List of
        [Service, Proto, Port] ->
            {withdraw, Service, Proto, Port};
        Whatever ->
            {bad_withdraw, Whatever}
    end.

request(List) ->
    case List of
        [Service, Proto] ->
            {request, Service, Proto};
        [Service] ->
            {request, Service};
        Whatever ->
            {bad_request, Whatever}
    end.
