-module(udp_spc).
-copyright('Copyright (c) 1991-97 Ericsson Telecom AB').
-vsn('$Revision: /main/release/2 $ ').

-export([start/1, init/2, system_continue/3,
	 system_terminate/4, write_debug/3, 
	 do_something/2, show_state/0]).

-define(PORTNO, 5151).

-record(state, {socket}).

start(Options) ->
    case whereis(udp_server) of
	undefined ->
	    Pid = proc_lib:spawn_link(?MODULE, init, [self(), Options]),
	    register(udp_server, Pid),
	    {ok, Pid};
	Pid ->
	    {error, {already_started, Pid}}
    end.

init(Parent, Options) ->
    process_flag(trap_exit, true),
    Deb = sys:debug_options(Options),
    case gen_udp:open(?PORTNO, [list]) of
	{ok, S} ->
	    loop(#state{socket = S}, Parent, Deb);
	{error, Reason} ->
	    exit(Reason)
    end.

loop(State, Parent, Deb) ->
    receive
	{system, From, Request} ->
	    sys:handle_system_msg(Request, From, Parent, ?MODULE, Deb, State);
	{'EXIT', Parent, Reason} ->
	    cleanup(State),
	    exit(Reason);
	{udp, Socket, IP, Port, Block} ->
	    NewDeb = sys:handle_debug(Deb, 
				      {?MODULE, write_debug},
				      udp_server, 
				      {in, {udp, Socket, IP, Port, Block}}),
	    Answer = spawn_link(?MODULE, do_something, [{udp, Socket, IP, Port, Block}, State]),
	    NewerDeb = sys:handle_debug(NewDeb, 
					{?MODULE, write_debug},
					udp_server, 
					{out, {self(), Answer}}),
	    loop(State, Parent, NewerDeb);
	show_state ->
	    NewDeb = sys:handle_debug(Deb, {?MODULE, write_debug},
				      udp_server, {in, show_state}),
	    io:fwrite("State is ~p~n", [State]),
	    loop(State, Parent, NewDeb);
	What ->
	    NewDeb = sys:handle_debug(Deb, {?MODULE, write_debug},
				      udp_server, {in, What}),
	    loop(State, Parent, NewDeb)
    end.

cleanup(State) ->
    gen_udp:close(State#state.socket),
    ok.

do_something({udp, Socket, IP, Port, Block}, State) ->
    gen_udp:send(Socket, IP, Port, "you said " ++ Block),
    {ok, State}.

show_state() ->
    udp_server ! show_state.

%% Here are the sys call back functions

system_continue(Parent, Deb, State) ->
    loop(State, Parent, Deb).

system_terminate(Reason, Parent, Deb, State) ->
    cleanup(State),
    exit(Reason).

write_debug(Dev, Event, Name) ->
    io:format(Dev, "~p event = ~p~n", [Name, Event]).
